==> xfe-0.99.tar.gz: xfe-0.99/src/icons.h <==
#ifndef ICONS_H
#define ICONS_H


// Prototypes
FXIcon* loadiconfile(FXApp *app, const FXString iconpath, const FXString iconname);
FXbool loadAppIcons(FXApp *app);


// Icons (global variables)
extern FXIcon *archaddicon;
extern FXIcon *archexticon;
extern FXIcon *attribicon;
extern FXIcon *bigappicon;
extern FXIcon *bigblockdevicon;
extern FXIcon *bigbrokenlinkicon;
extern FXIcon *bigcdromicon;
extern FXIcon *bigchardevicon;
extern FXIcon *bigdocicon;
extern FXIcon *bigexecicon;
extern FXIcon *bigfloppyicon;
extern FXIcon *bigfolderlockedicon;
extern FXIcon *bigfolderopenicon;
extern FXIcon *bigfoldericon;
extern FXIcon *bigfolderupicon;
extern FXIcon *bigharddiskicon;
extern FXIcon *bigiconsicon;
extern FXIcon *biglinkicon;
extern FXIcon *bignfsdriveicon;
extern FXIcon *bignfsdriveumticon;
extern FXIcon *bigpipeicon;
extern FXIcon *bigsocketicon;
extern FXIcon *bigzipicon;
extern FXIcon *cdromicon;
extern FXIcon *closefileicon;
extern FXIcon *clrbookicon;
extern FXIcon *colltreeicon;
extern FXIcon *copy_bigicon;
extern FXIcon *copy_clpicon;
extern FXIcon *cut_clpicon;
extern FXIcon *delete_big_permicon;
extern FXIcon *delete_bigicon;
extern FXIcon *deselicon;
extern FXIcon *detailsicon;
extern FXIcon *dirupicon;
extern FXIcon *editicon;
extern FXIcon *entericon;
extern FXIcon *errorbigicon;
extern FXIcon *exptreeicon;
extern FXIcon *filedelete_permicon;
extern FXIcon *filedeleteicon;
extern FXIcon *fileopenicon;
extern FXIcon *viewicon;
extern FXIcon *filtericon;
extern FXIcon *find_againicon;
extern FXIcon *fliplricon;
extern FXIcon *flipudicon;
extern FXIcon *floppyicon;
extern FXIcon *fontsicon;
extern FXIcon *gotobigicon;
extern FXIcon *gotolineicon;
extern FXIcon *harddiskicon;
extern FXIcon *helpicon;
extern FXIcon *hidehiddenicon;
extern FXIcon *hidenumbersicon;
extern FXIcon *hidethumbicon;
extern FXIcon *homeicon;
extern FXIcon *infobigicon;
extern FXIcon *invselicon;
extern FXIcon *link_bigicon;
extern FXIcon *locationicon;
extern FXIcon *lowercaseicon;
extern FXIcon *maphosticon;
extern FXIcon *miniappicon;
extern FXIcon *miniblockdevicon;
extern FXIcon *minibrokenlinkicon;
extern FXIcon *minichardevicon;
extern FXIcon *minidocicon;
extern FXIcon *miniexecicon;
extern FXIcon *minifolderclosedicon;
extern FXIcon *minifolderlockedicon;
extern FXIcon *minifolderopenicon;
extern FXIcon *minifoldericon;
extern FXIcon *minifolderupicon;
extern FXIcon *minilinkicon;
extern FXIcon *minipipeicon;
extern FXIcon *minishellicon;
extern FXIcon *minisocketicon;
extern FXIcon *move_bigicon;
extern FXIcon *moveiticon;
extern FXIcon *newfileicon;
extern FXIcon *newfoldericon;
extern FXIcon *nfsdriveicon;
extern FXIcon *nfsdriveumticon;
extern FXIcon *onepanelicon;
extern FXIcon *packageicon;
extern FXIcon *paste_clpicon;
extern FXIcon *prefsicon;
extern FXIcon *printbigicon;
extern FXIcon *printicon;
extern FXIcon *questionbigicon;
extern FXIcon *quiticon;
extern FXIcon *redoicon;
extern FXIcon *reloadicon;
extern FXIcon *renameiticon;
extern FXIcon *replaceicon;
extern FXIcon *reverticon;
extern FXIcon *rotatelefticon;
extern FXIcon *rotaterighticon;
extern FXIcon *runicon;
extern FXIcon *saveasicon;
extern FXIcon *savefileicon;
extern FXIcon *searchnexticon;
extern FXIcon *searchicon;
extern FXIcon *searchprevicon;
extern FXIcon *selallicon;
extern FXIcon *setbookicon;
extern FXIcon *shellicon;
extern FXIcon *showhiddenicon;
extern FXIcon *shownumbersicon;
extern FXIcon *showthumbicon;
extern FXIcon *smalliconsicon;
extern FXIcon *trash_full_bigicon;
extern FXIcon *trash_fullicon;
extern FXIcon *treeonepanelicon;
extern FXIcon *treetwopanelsicon;
extern FXIcon *twopanelsicon;
extern FXIcon *undoicon;
extern FXIcon *unmaphosticon;
extern FXIcon *uppercaseicon;
extern FXIcon *warningbigicon;
extern FXIcon *workicon;
extern FXIcon *wrapofficon;
extern FXIcon *wraponicon;
extern FXIcon *xfeicon;
extern FXIcon *xfiicon;
extern FXIcon *xfqicon;
extern FXIcon *xfvicon;
extern FXIcon *xfwicon;
extern FXIcon *zipicon;
extern FXIcon *zoom100icon;
extern FXIcon *zoominicon;
extern FXIcon *zoomouticon;
extern FXIcon *zoomwinicon;
extern FXIcon *totrashicon;
extern FXIcon *dirbackicon;
extern FXIcon *dirforwardicon;
extern FXIcon *minixferooticon;
extern FXIcon *minixfeicon;

#endif

==> xfe-1.04.tar.gz: xfe-1.04/src/icons.h <==
#ifndef ICONS_H
#define ICONS_H


// Prototypes
FXIcon* loadiconfile(FXApp *app, const FXString iconpath, const FXString iconname);
FXbool loadAppIcons(FXApp *app);


// Icons (global variables)
extern FXIcon *archaddicon;
extern FXIcon *archexticon;
extern FXIcon *attribicon;
extern FXIcon *bigappicon;
extern FXIcon *bigblockdevicon;
extern FXIcon *bigbrokenlinkicon;
extern FXIcon *bigcdromicon;
extern FXIcon *bigchardevicon;
extern FXIcon *bigdocicon;
extern FXIcon *bigexecicon;
extern FXIcon *bigfloppyicon;
extern FXIcon *bigfolderlockedicon;
extern FXIcon *bigfolderopenicon;
extern FXIcon *bigfoldericon;
extern FXIcon *bigfolderupicon;
extern FXIcon *bigharddiskicon;
extern FXIcon *bigiconsicon;
extern FXIcon *biglinkicon;
extern FXIcon *bignfsdriveicon;
extern FXIcon *bignfsdriveumticon;
extern FXIcon *bigpipeicon;
extern FXIcon *bigsocketicon;
extern FXIcon *bigzipicon;
extern FXIcon *cdromicon;
extern FXIcon *closefileicon;
extern FXIcon *clrbookicon;
extern FXIcon *colltreeicon;
extern FXIcon *copy_bigicon;
extern FXIcon *copy_clpicon;
extern FXIcon *cut_clpicon;
extern FXIcon *delete_big_permicon;
extern FXIcon *delete_bigicon;
extern FXIcon *deselicon;
extern FXIcon *detailsicon;
extern FXIcon *dirupicon;
extern FXIcon *editicon;
extern FXIcon *entericon;
extern FXIcon *errorbigicon;
extern FXIcon *exptreeicon;
extern FXIcon *filedelete_permicon;
extern FXIcon *filedeleteicon;
extern FXIcon *fileopenicon;
extern FXIcon *viewicon;
extern FXIcon *filtericon;
extern FXIcon *find_againicon;
extern FXIcon *fliplricon;
extern FXIcon *flipudicon;
extern FXIcon *floppyicon;
extern FXIcon *fontsicon;
extern FXIcon *gotobigicon;
extern FXIcon *gotolineicon;
extern FXIcon *harddiskicon;
extern FXIcon *helpicon;
extern FXIcon *hidehiddenicon;
extern FXIcon *hidenumbersicon;
extern FXIcon *hidethumbicon;
extern FXIcon *homeicon;
extern FXIcon *infobigicon;
extern FXIcon *invselicon;
extern FXIcon *link_bigicon;
extern FXIcon *locationicon;
extern FXIcon *lowercaseicon;
extern FXIcon *maphosticon;
extern FXIcon *miniappicon;
extern FXIcon *miniblockdevicon;
extern FXIcon *minibrokenlinkicon;
extern FXIcon *minichardevicon;
extern FXIcon *minidocicon;
extern FXIcon *miniexecicon;
extern FXIcon *minifolderclosedicon;
extern FXIcon *minifolderlockedicon;
extern FXIcon *minifolderopenicon;
extern FXIcon *minifoldericon;
extern FXIcon *minifolderupicon;
extern FXIcon *minilinkicon;
extern FXIcon *minipipeicon;
extern FXIcon *minishellicon;
extern FXIcon *minisocketicon;
extern FXIcon *move_bigicon;
extern FXIcon *moveiticon;
extern FXIcon *newfileicon;
extern FXIcon *newfoldericon;
extern FXIcon *nfsdriveicon;
extern FXIcon *nfsdriveumticon;
extern FXIcon *onepanelicon;
extern FXIcon *packageicon;
extern FXIcon *paste_clpicon;
extern FXIcon *prefsicon;
extern FXIcon *printbigicon;
extern FXIcon *printicon;
extern FXIcon *questionbigicon;
extern FXIcon *quiticon;
extern FXIcon *redoicon;
extern FXIcon *reloadicon;
extern FXIcon *renameiticon;
extern FXIcon *replaceicon;
extern FXIcon *reverticon;
extern FXIcon *rotatelefticon;
extern FXIcon *rotaterighticon;
extern FXIcon *runicon;
extern FXIcon *saveasicon;
extern FXIcon *savefileicon;
extern FXIcon *searchnexticon;
extern FXIcon *searchicon;
extern FXIcon *searchprevicon;
extern FXIcon *selallicon;
extern FXIcon *setbookicon;
extern FXIcon *shellicon;
extern FXIcon *showhiddenicon;
extern FXIcon *shownumbersicon;
extern FXIcon *showthumbicon;
extern FXIcon *smalliconsicon;
extern FXIcon *trash_full_bigicon;
extern FXIcon *trash_fullicon;
extern FXIcon *treeonepanelicon;
extern FXIcon *treetwopanelsicon;
extern FXIcon *twopanelsicon;
extern FXIcon *undoicon;
extern FXIcon *unmaphosticon;
extern FXIcon *uppercaseicon;
extern FXIcon *warningbigicon;
extern FXIcon *workicon;
extern FXIcon *wrapofficon;
extern FXIcon *wraponicon;
extern FXIcon *xfeicon;
extern FXIcon *xfiicon;
extern FXIcon *xfpicon;
extern FXIcon *xfvicon;
extern FXIcon *xfwicon;
extern FXIcon *zipicon;
extern FXIcon *zoom100icon;
extern FXIcon *zoominicon;
extern FXIcon *zoomouticon;
extern FXIcon *zoomwinicon;
extern FXIcon *totrashicon;
extern FXIcon *dirbackicon;
extern FXIcon *dirforwardicon;
extern FXIcon *minixferooticon;
extern FXIcon *minixfeicon;
extern FXIcon *filedialogicon;
extern FXIcon *bigarchaddicon;

#endif
